summaryrefslogtreecommitdiffstats
path: root/kmailcvt/filter_pmail.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'kmailcvt/filter_pmail.hxx')
-rw-r--r--kmailcvt/filter_pmail.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmailcvt/filter_pmail.hxx b/kmailcvt/filter_pmail.hxx
index 86f08ce6..664fdcc1 100644
--- a/kmailcvt/filter_pmail.hxx
+++ b/kmailcvt/filter_pmail.hxx
@@ -32,8 +32,8 @@ public:
void import(FilterInfo *info);
protected:
- /** this looks for all files with the filetqmask 'tqmask' and calls the 'workFunc' on each of them */
- void processFiles(const TQString& tqmask, void(FilterPMail::* workFunc)(const TQString&) );
+ /** this looks for all files with the filemask 'mask' and calls the 'workFunc' on each of them */
+ void processFiles(const TQString& mask, void(FilterPMail::* workFunc)(const TQString&) );
/** this function imports one *.CNM message */
void importNewMessage(const TQString& file);
/** this function imports one mail folder file (*.PMM) */
@@ -57,7 +57,7 @@ private:
1. type (2 for root-folder, 1 for folder, 0 for mailarchiv)
2. type (1 for root-folder, 3 for folder, 0 for mailarchiv)
3. "ID:flag:filename" of folder/archiv
- 4. "ID:name" of tqparent folder
+ 4. "ID:name" of parent folder
5. name of folder/archiv
*/
TQValueList<FolderStructure> folderMatrix;